;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "notmuch-transient" "20251101.2054"
  "Command dispatchers for Notmuch."
  '((emacs     "29.1")
    (compat    "30.1")
    (notmuch   "0.38")
    (transient "0.10"))
  :url "https://github.com/tarsius/notmuch-transient"
  :commit "09861654f1a25a46849f5653a4e9651d9a093ecd"
  :revdesc "09861654f1a2"
  :keywords '("mail")
  :authors '(("Jonas Bernoulli" . "emacs.notmuch-transient@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.notmuch-transient@jonas.bernoulli.dev")))
